@@ -22,6 +22,7 @@ from montecarlodata.integrations.onboarding.fields import (
     HIVE_MYSQL_CONNECTION_TYPE,
     HIVE_S3_CONNECTION_TYPE,
     PRESTO_S3_CONNECTION_TYPE,
+    DATABRICKS_METASTORE_CONNECTION_TYPE,
     S3_METADATA_EVENT_TYPE,
     S3_QL_EVENT_TYPE,
     SECRETS_MANAGER_CREDENTIAL_MECHANISM,
@@ -44,6 +45,7 @@ WAREHOUSE_VERBIAGE = 'For metadata, query logs and metrics'
 BI_VERBIAGE = 'For reports'
 PASSWORD_VERBIAGE = f'If you prefer a prompt (with hidden input) enter {settings.SHOW_PROMPT_VALUE}'
 RESOURCE_VERBIAGE = 'This can be helpful if the resources are in different accounts'
+CONNECTION_ID_VERBIAGE = 'ID for the connection.'
 
 # Options shared across commands
 ROLE_OPTIONS = [
@@ -67,7 +69,7 @@ DATABASE_OPTIONS = [
 ]
 
 CONNECTION_OPTIONS = [
-    click.option('--connection-id', help='ID for the connection.', required=True, type=click.UUID, callback=convert_uuid_callback)
+    click.option('--connection-id', help=CONNECTION_ID_VERBIAGE, required=True, type=click.UUID, callback=convert_uuid_callback)
 ]
 
 ONBOARDING_CONFIGURATION_OPTIONS = [
@@ -355,30 +357,25 @@ def toggle_airflow_log_events(ctx, toggle, role, **kwargs):
                                                                              **kwargs)
 
 
-@integrations.command(help=f'Toggle S3 metadata events for Hive/Presto. {EVENT_VERBIAGE}.')
+@integrations.command(help=f'Toggle S3 metadata events. {EVENT_VERBIAGE}.')
 @click.pass_obj
 @add_common_options(EVENT_OPTIONS)
+# Not using CONNECTION_OPTIONS as the value for "required" is different
+@click.option('--connection-id', help=CONNECTION_ID_VERBIAGE, required=False, type=click.UUID,
+              callback=convert_uuid_callback)
+@click.option('--connection-type', help='Type of the integration.', cls=AdvancedOptions,
+              mutually_exclusive_options=['connection_id'],
+              type=click.Choice(
+                  [HIVE_MYSQL_CONNECTION_TYPE, GLUE_CONNECTION_TYPE, DATABRICKS_METASTORE_CONNECTION_TYPE],
+                  case_sensitive=False))
 @click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def toggle_hive_metadata_events(ctx, toggle):
+def toggle_metadata_events(ctx, toggle, **kwargs):
     """
-    Toggle s3 metadata events for a hive lake
+    Toggle s3 metadata events for a lake
     """
     EventsOnboardingService(config=ctx['config']).toggle_event_configuration(enable=toggle,
-                                                                             connection_type=HIVE_MYSQL_CONNECTION_TYPE,
-                                                                             event_type=S3_METADATA_EVENT_TYPE)
-
-
-@integrations.command(help=f'Toggle S3 metadata events for Glue/Athena. {EVENT_VERBIAGE}.')
-@click.pass_obj
-@add_common_options(EVENT_OPTIONS)
-@click_config_file.configuration_option(settings.OPTION_FILE_FLAG)
-def toggle_glue_metadata_events(ctx, toggle):
-    """
-    Toggle s3 metadata events for a glue lake
-    """
-    EventsOnboardingService(config=ctx['config']).toggle_event_configuration(enable=toggle,
-                                                                             connection_type=GLUE_CONNECTION_TYPE,
-                                                                             event_type=S3_METADATA_EVENT_TYPE)
+                                                                             event_type=S3_METADATA_EVENT_TYPE,
+                                                                             **kwargs)
 
 
 @integrations.command(help=f'Toggle S3 query log events. {EVENT_VERBIAGE}.')
