@@ -31,7 +31,7 @@ class BaseOnboardingService:
         self._dc_outputs = None
 
         self._user_service = user_service or UserService(config=config)
-        self._request_wrapper = request_wrapper or GqlWrapper(mcd_id=config.mcd_id, mcd_token=config.mcd_token)
+        self._request_wrapper = request_wrapper or GqlWrapper(config)
         self._aws_wrapper = aws_wrapper or AwsClientWrapper(profile_name=config.aws_profile,
                                                             region_name=config.aws_region)
 
