@@ -127,8 +127,8 @@ mutation testSelfHostedCredentials($connectionType:String, $selfHostingMechanism
 """
 
 TOGGLE_EVENT_MUTATION = """
-mutation toggleEventConfig($dwId:UUID!, $enable:Boolean!, $connectionType:String!, $eventType:DataCollectorEventTypes!, $assumableRole:String, $externalId:String, $formatType:String, $sourceFormat:String, $mapping:JSONString) {
-  toggleEventConfig(dwId:$dwId, enable:$enable, connectionType:$connectionType, eventType: $eventType, assumableRole:$assumableRole, externalId:$externalId, formatType:$formatType, sourceFormat:$sourceFormat, mapping:$mapping){
+mutation toggleEventConfig($dwId:UUID, $enable:Boolean!, $connectionId:String, $connectionType:String, $eventType:DataCollectorEventTypes!, $assumableRole:String, $externalId:String, $formatType:String, $sourceFormat:String, $mapping:JSONString) {
+  toggleEventConfig(dwId:$dwId, enable:$enable, connectionId:$connectionId, connectionType:$connectionType, eventType: $eventType, assumableRole:$assumableRole, externalId:$externalId, formatType:$formatType, sourceFormat:$sourceFormat, mapping:$mapping){
     success
   }
 }
